@@ -9,15 +9,12 @@ import tomli
 import tomli_w
 from loguru import logger as log
 from packaging.version import Version, parse
-from stubber.codemod.enrich import enrich_folder
+from stubber.publish.bump import bump_postrelease
+from stubber.publish.enums import StubSource
 from stubber.publish.package import StubSource
 from stubber.utils.config import CONFIG
 from stubber.utils.versions import clean_version
 
-from .bump import bump_postrelease
-from .enums import StubSource
-from .merge_docstubs import copy_merge_docstubs
-
 # TODO: Get git tag and store in DB for reference
 # import stubber.basicgit as git
 # git log -n 1 --format="%H"
@@ -132,8 +129,10 @@ class StubPackage:
         return str(parse(pyproject["tool"]["poetry"]["version"]))
 
     @pkg_version.setter
-    def pkg_version(self, version):
+    def pkg_version(self, version: str):
         "set the version of the package"
+        if not isinstance(version, str):
+            version = str(version)
         # read the current file
         _toml = self.toml_path
         with open(_toml, "rb") as f:
@@ -246,22 +245,27 @@ class StubPackage:
         """
 
         # 1 - Copy  the stubs to the package, directly in the package folder (no folders)
-        for stub_type, fw_path in [s for s in self.stub_sources]:
+        # for stub_type, fw_path in [s for s in self.stub_sources]:
+        for n in range(len(self.stub_sources)):
+            stub_type, fw_path = self.stub_sources[n]
             if stub_type == StubSource.FIRMWARE:
                 # Check if -merged folder exists and copy that instead
                 merged_path = fw_path.with_name(f"{fw_path.name}-merged")
                 source = fw_path
-                if merged_path.exists():
+                if (CONFIG.stub_path / merged_path).exists():
+                    stub_type = StubSource.MERGED
                     source = merged_path
+                    # Update the source list
+                    self.stub_sources[n] = (stub_type, source)
                 try:
-                    log.debug(f"Copying {stub_type} from {source}")
+                    log.trace(f"Copying {stub_type} from {source}")
                     shutil.copytree(CONFIG.stub_path / source, self.package_path, symlinks=True, dirs_exist_ok=True)
                 except OSError as e:
                     log.error(f"Error copying stubs from : {CONFIG.stub_path / source}, {e}")
                     raise (e)
             else:
                 try:
-                    log.debug(f"Copying {stub_type} from {fw_path}")
+                    log.trace(f"Copying {stub_type} from {fw_path}")
                     shutil.copytree(CONFIG.stub_path / fw_path, self.package_path, symlinks=True, dirs_exist_ok=True)
                 except OSError as e:
                     log.error(f"Error copying stubs from : {CONFIG.stub_path / fw_path}, {e}")
@@ -426,26 +430,21 @@ class StubPackage:
     def is_changed(self) -> bool:
         "Check if the package has changed, based on the current and the stored hash"
         current = self.create_hash()
-        log.debug(f"changed: {self.hash != current} : Stored {self.hash} Current: {current}")
+        log.trace(f"changed: {self.hash != current} : Stored {self.hash} Current: {current}")
         return self.hash != current
 
-    def bump(self):
+    def bump(self) -> str:
         """
         bump the postrelease version of the package, and write the change to disk
         """
         try:
-            pyproject = self.pyproject
-            assert pyproject is not None, "No pyproject.toml file found"
-            current = parse(pyproject["tool"]["poetry"]["version"])
+            current = Version(self.pkg_version)
             assert isinstance(current, Version)
             # bump the version
-            new_version = bump_postrelease(current)
-            pyproject["tool"]["poetry"]["version"] = str(new_version)
-            self.pyproject = pyproject
+            self.pkg_version = str(bump_postrelease(current))
         except Exception as e:  # pragma: no cover
             log.error(f"Error: {e}")
-            return None
-        return new_version
+        return self.pkg_version
 
     def run_poetry(self, parameters: List[str]) -> bool:
         """Run a poetry commandline in the package folder.
@@ -473,6 +472,7 @@ class StubPackage:
             #   UploadError
             #   HTTP Error 400: File already exists. See https://test.pypi.org/help/#file-name-reuse for more information.
             # TODO: how to return the state so it can be handled
+            print()  # linefeed after output
             errors = [l for l in e.stdout.splitlines()[1:7] if "Error" in l]
             for e in errors:
                 log.error(e)
@@ -503,9 +503,11 @@ class StubPackage:
         # update the package info
         self.write_package_json()
         if production:
-            log.info(f"Publishing to PRODUCTION  https://pypy.org")
+            log.debug(f"Publishing to PRODUCTION  https://pypy.org")
             params = ["publish"]
         else:
-            log.info(f"Publishing to TEST-PyPi https://test.pypy.org")
+            log.debug(f"Publishing to TEST-PyPi https://test.pypy.org")
             params = ["publish", "-r", "test-pypi"]
-        return self.run_poetry(params)
+        r = self.run_poetry(params)
+        print("")  # add a newline after the output
+        return r
